@@ -1,10 +1,6 @@
 package Dist::Zilla::PluginBundle::GENEHACK;
-{
-  $Dist::Zilla::PluginBundle::GENEHACK::VERSION = '0.6';
-}
-BEGIN {
-  $Dist::Zilla::PluginBundle::GENEHACK::AUTHORITY = 'cpan:GENEHACK';
-}
+our $AUTHORITY = 'cpan:GENEHACK';
+$Dist::Zilla::PluginBundle::GENEHACK::VERSION = '0.700';
 # ABSTRACT: BeLike::GENEHACK when you zilla your dist
 
 
@@ -13,35 +9,43 @@ use namespace::autoclean;
 use Dist::Zilla;
 with 'Dist::Zilla::Role::PluginBundle::Easy';
 
+use Dist::Zilla::Plugin::GatherDir;
+
+use Dist::Zilla::PluginBundle::Filter;
 use Dist::Zilla::PluginBundle::Basic;
-use Dist::Zilla::PluginBundle::Git;
 
-use Dist::Zilla::Plugin::ArchiveRelease;
-use Dist::Zilla::Plugin::Authority;
-use Dist::Zilla::Plugin::AutoPrereqs;
-use Dist::Zilla::Plugin::Bugtracker;
-use Dist::Zilla::Plugin::CheckChangesHasContent;
-use Dist::Zilla::Plugin::CopyFilesFromBuild;
-use Dist::Zilla::Plugin::EOLTests;
-use Dist::Zilla::Plugin::ExtraTests;
 use Dist::Zilla::Plugin::Git::NextVersion;
-use Dist::Zilla::Plugin::GithubMeta;
-use Dist::Zilla::Plugin::Homepage;
-use Dist::Zilla::Plugin::InstallGuide;
-use Dist::Zilla::Plugin::InstallRelease;
+use Dist::Zilla::Plugin::AutoPrereqs;
+use Dist::Zilla::Plugin::CheckChangesHasContent;
+use Dist::Zilla::Plugin::Authority;
+use Dist::Zilla::Plugin::MinimumPerl;
+use Dist::Zilla::Plugin::PkgVersion;
+use Dist::Zilla::Plugin::TaskWeaver;
+use Dist::Zilla::Plugin::PodWeaver;
 use Dist::Zilla::Plugin::MetaConfig;
 use Dist::Zilla::Plugin::MetaJSON;
-use Dist::Zilla::Plugin::MinimumPerl;
+use Dist::Zilla::Plugin::GithubMeta;
+use Dist::Zilla::Plugin::InstallGuide;
+use Dist::Zilla::Plugin::CopyFilesFromBuild;
 use Dist::Zilla::Plugin::NextRelease;
-use Dist::Zilla::Plugin::PkgVersion;
+use Dist::Zilla::Plugin::ExtraTests;
 use Dist::Zilla::Plugin::PodCoverageTests;
 use Dist::Zilla::Plugin::PodSyntaxTests;
-use Dist::Zilla::Plugin::PodWeaver;
-use Dist::Zilla::Plugin::ReadmeMarkdownFromPod;
-use Dist::Zilla::Plugin::Repository;
-use Dist::Zilla::Plugin::TaskWeaver;
+use Dist::Zilla::Plugin::Test::EOL;
 use Dist::Zilla::Plugin::Test::Compile;
+use Dist::Zilla::Plugin::Git::Tag;
+use Dist::Zilla::Plugin::Git::Commit;
+use Dist::Zilla::Plugin::InstallRelease;
+use Dist::Zilla::Plugin::Git::Push;
 use Dist::Zilla::Plugin::Twitter;
+use Dist::Zilla::Plugin::Run;
+
+has homepage => (
+  is      => 'ro' ,
+  isa     => 'Maybe[Str]' ,
+  lazy    => 1 ,
+  default => sub { $_[0]->payload->{homepage} } ,
+);
 
 has is_task => (
   is      => 'ro',
@@ -53,81 +57,65 @@ has is_task => (
 sub configure {
   my $self = shift;
 
-  $self->add_bundle('Git');
+  $self->add_plugins(['GatherDir' => {
+    exclude_match    => '^release.*' ,
+    exclude_filename => [ 'dist.ini' , 'INSTALL' ],
+  }]);
+
+  $self->add_bundle('Filter' => {
+    bundle => '@Basic' ,
+    remove => [ 'GatherDir' , 'Readme' ] ,
+  });
 
   $self->add_plugins(
     # auto-versioning from git
-    [ 'Git::NextVersion' => { first_version => '0.01' } ],
-  );
+    'Git::NextVersion',
 
-  $self->add_bundle('Basic');
-
-  ## PLUGINS WHAT MUNGE MAKEFILE
-  $self->add_plugins(
     # automatically build deps list
     'AutoPrereqs' ,
-  );
 
-  ## PLUGINS WHAT MAKE SURE WE DON'T LOOK STUPID
-  $self->add_plugins(
     # does what it says on the tin
     'CheckChangesHasContent' ,
-  );
 
-  ## PLUGINS WHAT MUNGE CODE FILES
-  $self->add_plugins(
+    # include $VERSION in all files
+    'PkgVersion',
+
     # munge files to add authority info
     [ 'Authority' => { authority => 'cpan:GENEHACK' , do_metadata => 1 } ],
 
     # automagically determine minimum required perl version
     'MinimumPerl' ,
 
-    # include $VERSION in all files
-    'PkgVersion',
   );
 
   # weave together POD bits or build a task module
   if ($self->is_task) { $self->add_plugins('TaskWeaver') }
   else {                $self->add_plugins('PodWeaver')  }
 
-  ## PLUGINS WHAT MUNGE META.* FILES
   $self->add_plugins(
-    # auto-set info about bugtracker URL and mailto
-    'Bugtracker' ,
-
-    # auto-set homepage info
-    'Homepage' ,
-
     # include a bunch of dist::zilla meta info in META.* files
     'MetaConfig' ,
 
     # include a META.json file in addition to META.yml
     'MetaJSON' ,
-
-    # auto-set info about repository based on git config
-    #   specify 'github_http'=>0 b/c META.json has distinct keys for
-    #   repository url/web info
-    [ 'Repository' => { github_http => 0 } ],
-
   );
 
-  ## PLUGINS WHAT AUTO-GENERATE FILES
+  my $github_meta_config = { issues => 1 };
+  $github_meta_config->{homepage} = $self->homepage
+    if $self->homepage;
+
   $self->add_plugins(
+    [ 'GithubMeta' => $github_meta_config ] ,
+
     # auto-make INSTALL
     'InstallGuide' ,
 
-    # auto-generate a README.mkdn
-    'ReadmeMarkdownFromPod' ,
-
     # and copy it from the build
-    [ 'CopyFilesFromBuild' => { copy => 'README.mkdn' } ],
+    [ 'CopyFilesFromBuild' => { copy => 'INSTALL' } ],
 
     # munge Changes
     'NextRelease' ,
-  );
 
-  ## PLUGINS WHAT ADD TESTS
-  $self->add_plugins(
     # testing is good.
     'ExtraTests' ,
 
@@ -136,82 +124,110 @@ sub configure {
     'PodSyntaxTests' ,
 
     # oh, so very good
-    'EOLTests' ,
+    'Test::EOL' ,
     'Test::Compile' ,
-  );
 
-  ## PLUGINS WHAT DO STUFF
-  $self->add_plugins(
-    # tweet releases. because i can.
-    'Twitter' ,
     # git magic
-    'Git::Commit',
+    ['Git::Commit' => { add_files_in => 'releases/' } ],
     'Git::Tag',
+
     # install dist after release
     [ 'InstallRelease' => { install_command => 'cpanm .' } ] ,
-  );
 
-  ## PLUGINS WHAT NEED TO LOAD LATER THAN OTHERS
-  $self->add_plugins(
-    # save released dists under ./releases
-    'ArchiveRelease'
+    'Git::Push',
+
+    # tweet releases. because i can.
+    'Twitter' ,
+
+    ['Run::BeforeBuild' => {
+      run => 'rm -f Makefile.PL' ,
+    }],
+
+    ['Run::AfterBuild' => {
+      run => [
+        'cp %d/Makefile.PL ./' ,
+        "git status --porcelain | grep 'M Makefile.PL' && git commit -m 'auto-committed by dist.ini' Makefile.PL || echo Makefile.PL up to date" ,
+      ] ,
+    }],
+
+    ['Run::Release' => {
+      run          => 'mv %a ./releases/' ,
+      add_files_in => 'releases/' ,
+    }] ,
   );
 }
 
 1;
 
-
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Dist::Zilla::PluginBundle::GENEHACK - BeLike::GENEHACK when you zilla your dist
 
 =head1 VERSION
 
-version 0.6
+version 0.700
 
 =head1 SYNOPSIS
 
 Loads the stuff I find myself using all the time. Currently equivalent to
 this:
 
-    [@Git]
-    [Git::NextVersion]
-    first_version = 0.1
+    [GatherDir]
+    exclude_match    = ^release.*
+    exclude_filename = dist.ini
+    exclude_filename = INSTALL
 
-    [@Basic]
+    [@Filter]
+    -bundle = @Basic
+    -remove = GatherDir
+    -remove = Readme
+
+    [Git::NextVersion]
 
     [AutoPrereqs]
-    [Authority]
-    authority = 'cpan:GENEHACK'
-    do_metadata = 1
     [CheckChangesHasContent]
+    [Authority]
+    authority='cpan:GENEHACK'
+    do_metadata=1
     [MinimumPerl]
     [PkgVersion]
-    [PodWeaver]
-    [Bugtracker]
-    [Homepage]
+    [Taskweaver]   ; if is_task is set
+    [PodWeaver]    ; if is_task is NOT set
     [MetaConfig]
     [MetaJSON]
     [GithubMeta]
-    [Repository]
+    ; if needed, override homepage with 'homepage' param to @GENEHACK
+    issues = 1
     [InstallGuide]
-    [ReadmeMarkdownFromPod]
     [CopyFilesFromBuild]
-    copy = README.mkdn
+    copy=INSTALL
+    [NextRelease]
     [ExtraTests]
     [PodCoverageTests]
     [PodSyntaxTests]
     [EOLTests]
     [Test::Compile]
-    [Twitter]
-    [Git::Commit]
     [Git::Tag]
-    [ArchiveRelease]
+    [Git::Commit]
+    add_files_in = releases/
     [InstallRelease]
-    [NextRelease]
+    install_command='cpanm .'
+    [Git::Push]
+    [Twitter]
+    [Run::BeforeBuild]
+    run = rm -f Makefile.PL
+    [Run::AfterBuild]
+    run = cp %d/Makefile.PL ./
+    run = git status --porcelain | grep 'M Makefile.PL' && git commit -m 'auto-committed by dist.ini' Makefile.PL || echo Makefile.PL up to date
+    [Run::Release]
+    run = mv %a ./releases/
+    add_files_in = releases/
 
 =for Pod::Coverage configure
 
@@ -221,10 +237,9 @@ John SJ Anderson <genehack@genehack.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by John SJ Anderson.
+This software is copyright (c) 2015 by John SJ Anderson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
